#
# spec file for package memkind
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           memkind
Summary:        User Extensible Heap Manager
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Version:        1.14.0
Release:        2.4
URL:            http://memkind.github.io/memkind
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  unzip
%if %{defined suse_version}
BuildRequires:  libnuma-devel
%else
BuildRequires:  numactl-devel
%endif

%define namespace memkind

%if %{defined suse_version}
%define docdir %{_defaultdocdir}/%{namespace}
%else
%define docdir %{_defaultdocdir}/%{namespace}-%{version}
%endif

ExclusiveArch:  x86_64 aarch64 ppc64 ppc64le s390x

# default values if version is a tagged release on github
%{!?commit: %define commit %{version}}
%{!?buildsubdir: %define buildsubdir %{namespace}-%{commit}}
Source0:        https://github.com/%{namespace}/%{namespace}/archive/v%{commit}/%{buildsubdir}.tar.gz
Patch0:         memkind-fix-build.diff
Patch1:         memkind-dont-redefine-fortify.diff

%description
The memkind library is an user extensible heap manager built on top
of jemalloc which enables control of memory characteristics and a
partitioning of the heap between kinds of memory.

%package -n libmemkind0
Summary:        User Extensible Heap Manager shared library
Group:          System/Libraries

%description -n libmemkind0
The memkind library is an user extensible heap manager built on top
of jemalloc which enables control of memory characteristics and a
partitioning of the heap between kinds of memory. The kinds of memory
are defined by operating system memory policies that have been
applied to virtual address ranges. Memory characteristics supported
by memkind without user extension include control of NUMA and page
size features. The jemalloc non-standard interface has been extended
to enable specialized arenas to make requests for virtual memory from
the operating system through the memkind partition interface. Through
the other memkind interfaces, the user can control and extend memory
partition features and allocate memory while selecting enabled
features.

%package devel
Summary:        Development files for the "memkind" user extensible heap manager
Group:          Development/Libraries/C and C++
Requires:       libmemkind0 = %{version}-%{release}

%description devel
Header files for building applications with libmemkind.

%prep
%autosetup -p0 -n memkind-%{version}

%build

export JE_PREFIX=jemk_

# Build memkind lib and tools
cd %{_builddir}/%{buildsubdir}
echo %{version} > %{_builddir}/%{buildsubdir}/VERSION
test -f configure || ./autogen.sh
%configure --docdir=%{_docdir}/%{namespace} --disable-static
%{__make} %{?_smp_mflags}

%install
cd %{_builddir}/%{buildsubdir}
%{__make} DESTDIR=%{buildroot} install
# remove unwanted libs
rm -f %{buildroot}/libautohbw.*
rm -f %{buildroot}/%{_libdir}/lib%{namespace}.la
rm -f %{buildroot}/%{_libdir}/lib{numakind,autohbw,memtier}.*
rm -f %{buildroot}/%{_mandir}/man7/autohbw.*
rm -f %{buildroot}/%{_mandir}/man7/memtier.*

%post -n libmemkind0 -p /sbin/ldconfig

%postun -n libmemkind0 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%license %{_docdir}/%{namespace}/COPYING
%doc %{_docdir}/%{namespace}/README
%doc %{_docdir}/%{namespace}/VERSION
%dir %{_docdir}/%{namespace}
%{_bindir}/%{namespace}-hbw-nodes
%{_bindir}/%{namespace}-auto-dax-kmem-nodes
%{_bindir}/memtier
%{_mandir}/man1/memkind-hbw-nodes.1.*
%{_mandir}/man1/memkind-auto-dax-kmem-nodes.1.*
%{_mandir}/man1/memtier.1.*
%{_mandir}/man7/libmemtier.7.*

%files -n libmemkind0
%{_libdir}/lib%{namespace}.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/hbwmalloc.h
%{_includedir}/hbw_allocator.h
%{_includedir}/memkind_deprecated.h
%{_includedir}/memkind_allocator.h
%{_includedir}/pmem_allocator.h
%{_includedir}/memkind_memtier.h
%{_includedir}/fixed_allocator.h
%{_libdir}/lib%{namespace}.so
%{_libdir}/pkgconfig/memkind.pc
%{_includedir}/%{namespace}.h
%{_mandir}/man3/hbwmalloc.3.*
%{_mandir}/man3/hbwallocator.3.*
%{_mandir}/man3/%{namespace}*.3.*
%{_mandir}/man3/pmemallocator.3.*
%{_mandir}/man3/fixedallocator.3.*
%{_mandir}/man3/libmemtier.3.*

%changelog
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Nov 10 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.14.0
  + Provided a memtier binary for common uses of memory tiering
  + Added memkind memtier API header file to installed headers
  + Added missing information in memkind memtier manpages
  + Upgraded jemalloc internal library to version 5.3.0
  - Fixes to security issues
  + Added fixed kind for user-supplied memory area (along with the C++ allocator)
  + Provided a function memkind_get_capacity() to get the memory capacity of nodes available
    to a given kind
  + Added logging to file mechanism (enabled with an --enable-logging-to-file configure parameter)
  + Fixed wrong NUMA nodes masks for some of static kinds
  + Fixed building for different malloc_usable_size() implementations
* Thu Jun 23 2022 Michael Matz <matz@suse.com>
- Add memkind-dont-redefine-fortify.diff to not redefine
  _FORTIFY_SOURCE if already included in CFLAGS.
* Thu Sep 30 2021 Antoine Ginies <aginies@suse.com>
- update to version 1.12.0 (JSC#SLE-22050)
  * Optimized hog memory
  * Removed memkind_malloc_wrapper
  * Extended error handling in pmem_allocator
  From version 1.11.0:
  * Provided a function to verify if path supports DAX - memkind_check_dax_path()
  * Provided a NUMA node interleave variant for MEMKIND_DAX_KMEM (MEMKIND_DAX_KMEM_INTERLEAVE)
  * Provided a function to enable/disable background threads - memkind_set_bg_threads()
  * Provided a function to print statistics - memkind_stats_print()
  * Extended configure mechanism by enable-memkind-initial-exec-tls option
  * Extended memkind to support HMAT (libhwloc required)
  * Provided memory property abstraction (MEMKIND_HIGHEST_CAPACITY*, MEMKIND_LOWEST_LATENCY_LOCAL*, MEMKIND_HIGHEST_BANDWIDTH_LOCAL*)
  * Extended support for MEMKIND_HBW* to platforms with full HMAT support (kernel+hardware)
* Mon Jan 25 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable build on aarch64
* Mon Dec 14 2020 Wang Jun <jgwang@suse.com>
- Update to version 1.10.1
  * Fixed calculation size for pmem kind
  * Add support for MEMKIND_HOG_MEMORY in pmem kind
  * Fixed memkind_defrag_reallocate
  * Extended configure mechanism by MIN_LG_ALIGN parameter and disable-heap-manager options
  * Optimized searching command in mallctl, memkind_defrag_reallocate and memkind_detect_kind methods
  * Removed punch-hole in destroy extent operation
- Removed the patch Add-missing-includes.patch, it
  was merged into upstream.
* Tue Oct 13 2020 Christian Vögl <christian.voegl@suse.com>
- Add Buildrequires pkg-config to generate pkg-config provides
* Tue Aug 18 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Enable memkind builds for ppc64, ppc64le and s390x
- Update memking to version 1.10.0 with these changes:
  * Provided another way to use Persistent Memory in memkind (MEMKIND_DAX_KMEM_* kinds)
  * Added C++ allocator for static kinds (including MEMKIND_DAX_KMEM_* kinds)
  * Provided an interface to get memkind allocation statistics
  * Provided a method to reduce fragmentation - memkind_defrag_reallocate()
  * Added support for background thread
  * Updated internally used jemalloc to upstream version 5.2.1
  * Extended hbw interface with hbw_malloc_usable_size()
  * Simplified building process
- Rebase memkind-fix-build.diff .
- Backport Add-missing-includes.patch from upstream to fix compilation
  with GCC10
- Use %%configure for building
* Tue Dec 10 2019 matz@suse.com
- Update memkind to version 1.9.0 (jsc#SLE-8598 aka jsc#SLE-8515,
  jsc#SLE-10102 aka jsc#SLE-7950)
  with these changes since 1.8.0:
  * Provided a second function to create PMEM kind
    memkind_create_pmem_with_config()
  * Provided the memkind_detect_kind() function to recognize
    a kind from memory allocation
  * Provided memkind_config_set_memory_usage_policy() function
    that modifies the default memory usage policy behavior
  * Provided the ability to pass a NULL kind to
    memkind_malloc_usable_size() and memkind_realloc()
  * Unified the memkind_realloc() behavior for all kinds
  * Added the support for the pool_msize() function to TBB
  * Extended build arch to ppc64, ppc64le, s390x
  * Removed disable-stats from used jemalloc
  * Fixed compilation under the Clang and rpm build configuration
  * Provided support for Dockerfile
- Also includes these changes since 1.7.0:
  * Fixed error with realloc/free method with passing
    thread-specific cache flag
  * Fixed error with memkind_create_pmem(), if other PMEM kind
    was destroyed before
  * Fixed error with zeroing large allocations in PMEM kind
  * Added support to create kind without maximum size limit of
    PMEM kind (max_size=0)
  * Extended memkind API with memkind_malloc_usable_size()
  * Removed EXPERIMENTAL from most methods in memkind API
  * Added MEMKIND_ERROR_ARENAS_CREATE code
  * Added C++ allocator for PMEM kind
  * Extended PMEM examples
  * Fixed integration with Travis CI
  * Extended Travis CI configuration with Astyle and Coverage
  * Added PMEM kind tests
- Also includes these changes since 1.6.0:
  * Updated internally used jemalloc to upstream version 5.0.
  * Fixed error that has been occuring while memkind was
    dynamically loaded.
  * Fixed MEMKIND_HBW_NODES behavior for single NUMA node system.
  * Removed licenses other than BSD 3-clause from COPYING.
  * Changed build instructions.
  * Added configurable jemalloc prefix in build scripts.
  * Upgraded gtest to version 1.8.0.
  * Added memory footprint tests.
  * Added locality test for MEMKIND_PREFERRED.
  * Applied test parametrization in BATests.
  * Fixed problems with pytest testing in Travis.
  * Added huge page configuration in several tests.
  * Removed several symbols that are no longer exposed in
    public API from man pages.
  * Fixed HBW_POLICY_BIND_ALL documentation.
- Rebase memkind-fix-build.diff .
* Fri Nov 17 2017 matz@suse.com
- Update memkind to version 1.6.0 (fate #321932):
  * Deprecated some functions: memkind_create(), memkind_ops,
    memkind_finalize(), memkind_get_num_kind(),
    memkind_get_kind_by_partition(), memkind_get_kind_by_name(),
    memkind_partition_mmap(), memkind_get_size().
  * Introduced hbw_verify_memory_region() for checking HBWness
  * Added memkind_create_kind(), memkind_destroy_kind().
  * Updated internal jemalloc to 4.3.1
  * Add envvar MEMKIND_HOG_MEMORY preventing memkind from releasing
    memory to OS.
  * Deprecated support for gigabyte-pages
  * Deprecated the headers from memkind/internal
  * Allocation time optimizations with up to 20%% improvement
  * Introduced logging mechanism
  * Cleanup of symbols exposed by libmemkind.so
  * Introduced policy HBW_POLICY_BIND_ALL and MEMKIND_HBW_ALL,
    MEMKIND_HBW_ALL_HUGETLB and MEMKIND_REGULAR kinds
- Removed gtest-1.7.0.zip (tests now included fused gtest sources)
- Adjust patch memkind-fix-build.diff
* Fri Jul 22 2016 jengelh@inai.de
- Re-set RPM groups for openSUSE. Make description available in
  the most prominently installed package. Fix a wrong Require tag.
* Fri Jul 22 2016 matz@suse.com
- Replace memkind-1.1.0.tar.bz2 with memkind-1.1.0.tar.gz; github
  only supports tar.gz downloads.
- Use --disable-static instead of deleting the static library
  afterwards.
* Fri Jul 22 2016 matz@suse.com
- Create libmemkind0 subpackage for shared library policy.
* Fri Jun 10 2016 matz@suse.com
- Initial package (git tag v1.1.0)
- Add memkind-fix-build.diff for our AS_NEEDED setup.
